=====
FPL Analytics
=====

fpl analytics is a python utility to perform fantasy premier league analytics.

Detailed documentation is in the "docs" directory.

Creating Packages
-----------------
refer - https://packaging.python.org/tutorials/packaging-projects/

Quick start
-----------
1. pip install --upgrade git+git://github.com/rahulspsec/fpl_analytics.git
